#[doc = r"Register block"]
#[repr(C)]
pub struct RegisterBlock {
    #[doc = "0x00 - Flushes FIFO"]
    pub flush: FLUSH,
    #[doc = "0x04 - Set or clear DMA write request"]
    pub dma_req: DMA_REQ,
    #[doc = "0x08 - Indicates FIFO fill level status"]
    pub fifo_sts: FIFO_STS,
    #[doc = "0x0c - Configures FIFO fill level that triggers interrupt and packing 1 or 2 samples per word."]
    pub fifo_cfg: FIFO_CFG,
    #[doc = "0x10 - Enable software trigger to start descriptor processing"]
    pub trigger: TRIGGER,
    #[doc = "0x14 - Indicates active descriptor table and descriptor entry"]
    pub dscr_sts: DSCR_STS,
    #[doc = "0x18 - Set or clear power down mode"]
    pub power_down: POWER_DOWN,
    #[doc = "0x1c - Configures external trigger mode, store channel ID in FIFO and walk-up recovery time from power down."]
    pub config: CONFIG,
    #[doc = "0x20 - Configures window comparator A levels."]
    pub thr_a: THR_A,
    #[doc = "0x24 - Configures window comparator B levels."]
    pub thr_b: THR_B,
    #[doc = "0x28 - Contains last converted sample of input M \\[M=0..5) and result of window comparator."]
    pub last_sample: [LAST_SAMPLE; 6],
    _reserved11: [u8; 196usize],
    #[doc = "0x104 - ADC speed control"]
    pub adc_speed: ADC_SPEED,
    #[doc = "0x108 - Configures ADC power vs. speed, DC-in biasing, output format and power gating."]
    pub power_control: POWER_CONTROL,
    _reserved13: [u8; 244usize],
    #[doc = "0x200 - FIFO output mapped to 16 consecutive address locations. An output contains the value and input channel ID of one or two converted samples"]
    pub fifo_output: [FIFO_OUTPUT; 16],
    _reserved14: [u8; 192usize],
    #[doc = "0x300 - Table 0 descriptor n, n= 0 to 7"]
    pub descriptor0_: [DESCRIPTOR0_; 8],
    #[doc = "0x320 - Table 1 descriptors n, n=0 to 7"]
    pub descriptor1_: [DESCRIPTOR1_; 8],
    _reserved16: [u8; 3008usize],
    #[doc = "0xf00 - Interrupt 0 clear mask"]
    pub clr_en0: CLR_EN0,
    #[doc = "0xf04 - Interrupt 0 set mask"]
    pub set_en0: SET_EN0,
    #[doc = "0xf08 - Interrupt 0 mask"]
    pub mask0: MASK0,
    #[doc = "0xf0c - Interrupt 0 status. Interrupt 0 contains FIFO fill level, descriptor status and ADC range under/overflow"]
    pub status0: STATUS0,
    #[doc = "0xf10 - Interrupt 0 clear status"]
    pub clr_stat0: CLR_STAT0,
    #[doc = "0xf14 - Interrupt 0 set status"]
    pub set_stat0: SET_STAT0,
    _reserved22: [u8; 8usize],
    #[doc = "0xf20 - Interrupt 1 mask clear enable."]
    pub clr_en1: CLR_EN1,
    #[doc = "0xf24 - Interrupt 1 mask set enable"]
    pub set_en1: SET_EN1,
    #[doc = "0xf28 - Interrupt 1 mask"]
    pub mask1: MASK1,
    #[doc = "0xf2c - Interrupt 1 status. Interrupt 1 contains window comparator results and register last LAST_SAMPLE\\[M\\] overrun."]
    pub status1: STATUS1,
    #[doc = "0xf30 - Interrupt 1 clear status"]
    pub clr_stat1: CLR_STAT1,
    #[doc = "0xf34 - Interrupt 1 set status"]
    pub set_stat1: SET_STAT1,
}
#[doc = "Flushes FIFO\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [flush](flush) module"]
pub type FLUSH = crate::Reg<u32, _FLUSH>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _FLUSH;
#[doc = "`write(|w| ..)` method takes [flush::W](flush::W) writer structure"]
impl crate::Writable for FLUSH {}
#[doc = "Flushes FIFO"]
pub mod flush;
#[doc = "Set or clear DMA write request\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [dma_req](dma_req) module"]
pub type DMA_REQ = crate::Reg<u32, _DMA_REQ>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DMA_REQ;
#[doc = "`read()` method returns [dma_req::R](dma_req::R) reader structure"]
impl crate::Readable for DMA_REQ {}
#[doc = "`write(|w| ..)` method takes [dma_req::W](dma_req::W) writer structure"]
impl crate::Writable for DMA_REQ {}
#[doc = "Set or clear DMA write request"]
pub mod dma_req;
#[doc = "Indicates FIFO fill level status\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [fifo_sts](fifo_sts) module"]
pub type FIFO_STS = crate::Reg<u32, _FIFO_STS>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _FIFO_STS;
#[doc = "`read()` method returns [fifo_sts::R](fifo_sts::R) reader structure"]
impl crate::Readable for FIFO_STS {}
#[doc = "Indicates FIFO fill level status"]
pub mod fifo_sts;
#[doc = "Configures FIFO fill level that triggers interrupt and packing 1 or 2 samples per word.\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [fifo_cfg](fifo_cfg) module"]
pub type FIFO_CFG = crate::Reg<u32, _FIFO_CFG>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _FIFO_CFG;
#[doc = "`read()` method returns [fifo_cfg::R](fifo_cfg::R) reader structure"]
impl crate::Readable for FIFO_CFG {}
#[doc = "`write(|w| ..)` method takes [fifo_cfg::W](fifo_cfg::W) writer structure"]
impl crate::Writable for FIFO_CFG {}
#[doc = "Configures FIFO fill level that triggers interrupt and packing 1 or 2 samples per word."]
pub mod fifo_cfg;
#[doc = "Enable software trigger to start descriptor processing\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [trigger](trigger) module"]
pub type TRIGGER = crate::Reg<u32, _TRIGGER>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _TRIGGER;
#[doc = "`write(|w| ..)` method takes [trigger::W](trigger::W) writer structure"]
impl crate::Writable for TRIGGER {}
#[doc = "Enable software trigger to start descriptor processing"]
pub mod trigger;
#[doc = "Indicates active descriptor table and descriptor entry\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [dscr_sts](dscr_sts) module"]
pub type DSCR_STS = crate::Reg<u32, _DSCR_STS>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DSCR_STS;
#[doc = "`read()` method returns [dscr_sts::R](dscr_sts::R) reader structure"]
impl crate::Readable for DSCR_STS {}
#[doc = "`write(|w| ..)` method takes [dscr_sts::W](dscr_sts::W) writer structure"]
impl crate::Writable for DSCR_STS {}
#[doc = "Indicates active descriptor table and descriptor entry"]
pub mod dscr_sts;
#[doc = "Set or clear power down mode\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [power_down](power_down) module"]
pub type POWER_DOWN = crate::Reg<u32, _POWER_DOWN>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _POWER_DOWN;
#[doc = "`read()` method returns [power_down::R](power_down::R) reader structure"]
impl crate::Readable for POWER_DOWN {}
#[doc = "`write(|w| ..)` method takes [power_down::W](power_down::W) writer structure"]
impl crate::Writable for POWER_DOWN {}
#[doc = "Set or clear power down mode"]
pub mod power_down;
#[doc = "Configures external trigger mode, store channel ID in FIFO and walk-up recovery time from power down.\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [config](config) module"]
pub type CONFIG = crate::Reg<u32, _CONFIG>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CONFIG;
#[doc = "`read()` method returns [config::R](config::R) reader structure"]
impl crate::Readable for CONFIG {}
#[doc = "`write(|w| ..)` method takes [config::W](config::W) writer structure"]
impl crate::Writable for CONFIG {}
#[doc = "Configures external trigger mode, store channel ID in FIFO and walk-up recovery time from power down."]
pub mod config;
#[doc = "Configures window comparator A levels.\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [thr_a](thr_a) module"]
pub type THR_A = crate::Reg<u32, _THR_A>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _THR_A;
#[doc = "`read()` method returns [thr_a::R](thr_a::R) reader structure"]
impl crate::Readable for THR_A {}
#[doc = "`write(|w| ..)` method takes [thr_a::W](thr_a::W) writer structure"]
impl crate::Writable for THR_A {}
#[doc = "Configures window comparator A levels."]
pub mod thr_a;
#[doc = "Configures window comparator B levels.\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [thr_b](thr_b) module"]
pub type THR_B = crate::Reg<u32, _THR_B>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _THR_B;
#[doc = "`read()` method returns [thr_b::R](thr_b::R) reader structure"]
impl crate::Readable for THR_B {}
#[doc = "`write(|w| ..)` method takes [thr_b::W](thr_b::W) writer structure"]
impl crate::Writable for THR_B {}
#[doc = "Configures window comparator B levels."]
pub mod thr_b;
#[doc = "Contains last converted sample of input M \\[M=0..5) and result of window comparator.\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [last_sample](last_sample) module"]
pub type LAST_SAMPLE = crate::Reg<u32, _LAST_SAMPLE>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _LAST_SAMPLE;
#[doc = "`read()` method returns [last_sample::R](last_sample::R) reader structure"]
impl crate::Readable for LAST_SAMPLE {}
#[doc = "Contains last converted sample of input M \\[M=0..5) and result of window comparator."]
pub mod last_sample;
#[doc = "ADC speed control\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [adc_speed](adc_speed) module"]
pub type ADC_SPEED = crate::Reg<u32, _ADC_SPEED>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ADC_SPEED;
#[doc = "`read()` method returns [adc_speed::R](adc_speed::R) reader structure"]
impl crate::Readable for ADC_SPEED {}
#[doc = "`write(|w| ..)` method takes [adc_speed::W](adc_speed::W) writer structure"]
impl crate::Writable for ADC_SPEED {}
#[doc = "ADC speed control"]
pub mod adc_speed;
#[doc = "Configures ADC power vs. speed, DC-in biasing, output format and power gating.\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [power_control](power_control) module"]
pub type POWER_CONTROL = crate::Reg<u32, _POWER_CONTROL>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _POWER_CONTROL;
#[doc = "`read()` method returns [power_control::R](power_control::R) reader structure"]
impl crate::Readable for POWER_CONTROL {}
#[doc = "`write(|w| ..)` method takes [power_control::W](power_control::W) writer structure"]
impl crate::Writable for POWER_CONTROL {}
#[doc = "Configures ADC power vs. speed, DC-in biasing, output format and power gating."]
pub mod power_control;
#[doc = "FIFO output mapped to 16 consecutive address locations. An output contains the value and input channel ID of one or two converted samples\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [fifo_output](fifo_output) module"]
pub type FIFO_OUTPUT = crate::Reg<u32, _FIFO_OUTPUT>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _FIFO_OUTPUT;
#[doc = "`read()` method returns [fifo_output::R](fifo_output::R) reader structure"]
impl crate::Readable for FIFO_OUTPUT {}
#[doc = "FIFO output mapped to 16 consecutive address locations. An output contains the value and input channel ID of one or two converted samples"]
pub mod fifo_output;
#[doc = "Table 0 descriptor n, n= 0 to 7\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [descriptor0_](descriptor0_) module"]
pub type DESCRIPTOR0_ = crate::Reg<u32, _DESCRIPTOR0_>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DESCRIPTOR0_;
#[doc = "`read()` method returns [descriptor0_::R](descriptor0_::R) reader structure"]
impl crate::Readable for DESCRIPTOR0_ {}
#[doc = "`write(|w| ..)` method takes [descriptor0_::W](descriptor0_::W) writer structure"]
impl crate::Writable for DESCRIPTOR0_ {}
#[doc = "Table 0 descriptor n, n= 0 to 7"]
pub mod descriptor0_;
#[doc = "Table 1 descriptors n, n=0 to 7\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [descriptor1_](descriptor1_) module"]
pub type DESCRIPTOR1_ = crate::Reg<u32, _DESCRIPTOR1_>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DESCRIPTOR1_;
#[doc = "`read()` method returns [descriptor1_::R](descriptor1_::R) reader structure"]
impl crate::Readable for DESCRIPTOR1_ {}
#[doc = "`write(|w| ..)` method takes [descriptor1_::W](descriptor1_::W) writer structure"]
impl crate::Writable for DESCRIPTOR1_ {}
#[doc = "Table 1 descriptors n, n=0 to 7"]
pub mod descriptor1_;
#[doc = "Interrupt 0 clear mask\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [clr_en0](clr_en0) module"]
pub type CLR_EN0 = crate::Reg<u32, _CLR_EN0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CLR_EN0;
#[doc = "`write(|w| ..)` method takes [clr_en0::W](clr_en0::W) writer structure"]
impl crate::Writable for CLR_EN0 {}
#[doc = "Interrupt 0 clear mask"]
pub mod clr_en0;
#[doc = "Interrupt 0 set mask\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [set_en0](set_en0) module"]
pub type SET_EN0 = crate::Reg<u32, _SET_EN0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SET_EN0;
#[doc = "`write(|w| ..)` method takes [set_en0::W](set_en0::W) writer structure"]
impl crate::Writable for SET_EN0 {}
#[doc = "Interrupt 0 set mask"]
pub mod set_en0;
#[doc = "Interrupt 0 mask\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [mask0](mask0) module"]
pub type MASK0 = crate::Reg<u32, _MASK0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MASK0;
#[doc = "`read()` method returns [mask0::R](mask0::R) reader structure"]
impl crate::Readable for MASK0 {}
#[doc = "Interrupt 0 mask"]
pub mod mask0;
#[doc = "Interrupt 0 status. Interrupt 0 contains FIFO fill level, descriptor status and ADC range under/overflow\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [status0](status0) module"]
pub type STATUS0 = crate::Reg<u32, _STATUS0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _STATUS0;
#[doc = "`read()` method returns [status0::R](status0::R) reader structure"]
impl crate::Readable for STATUS0 {}
#[doc = "Interrupt 0 status. Interrupt 0 contains FIFO fill level, descriptor status and ADC range under/overflow"]
pub mod status0;
#[doc = "Interrupt 0 clear status\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [clr_stat0](clr_stat0) module"]
pub type CLR_STAT0 = crate::Reg<u32, _CLR_STAT0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CLR_STAT0;
#[doc = "`write(|w| ..)` method takes [clr_stat0::W](clr_stat0::W) writer structure"]
impl crate::Writable for CLR_STAT0 {}
#[doc = "Interrupt 0 clear status"]
pub mod clr_stat0;
#[doc = "Interrupt 0 set status\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [set_stat0](set_stat0) module"]
pub type SET_STAT0 = crate::Reg<u32, _SET_STAT0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SET_STAT0;
#[doc = "`write(|w| ..)` method takes [set_stat0::W](set_stat0::W) writer structure"]
impl crate::Writable for SET_STAT0 {}
#[doc = "Interrupt 0 set status"]
pub mod set_stat0;
#[doc = "Interrupt 1 mask clear enable.\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [clr_en1](clr_en1) module"]
pub type CLR_EN1 = crate::Reg<u32, _CLR_EN1>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CLR_EN1;
#[doc = "`write(|w| ..)` method takes [clr_en1::W](clr_en1::W) writer structure"]
impl crate::Writable for CLR_EN1 {}
#[doc = "Interrupt 1 mask clear enable."]
pub mod clr_en1;
#[doc = "Interrupt 1 mask set enable\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [set_en1](set_en1) module"]
pub type SET_EN1 = crate::Reg<u32, _SET_EN1>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SET_EN1;
#[doc = "`write(|w| ..)` method takes [set_en1::W](set_en1::W) writer structure"]
impl crate::Writable for SET_EN1 {}
#[doc = "Interrupt 1 mask set enable"]
pub mod set_en1;
#[doc = "Interrupt 1 mask\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [mask1](mask1) module"]
pub type MASK1 = crate::Reg<u32, _MASK1>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _MASK1;
#[doc = "`read()` method returns [mask1::R](mask1::R) reader structure"]
impl crate::Readable for MASK1 {}
#[doc = "Interrupt 1 mask"]
pub mod mask1;
#[doc = "Interrupt 1 status. Interrupt 1 contains window comparator results and register last LAST_SAMPLE\\[M\\] overrun.\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [status1](status1) module"]
pub type STATUS1 = crate::Reg<u32, _STATUS1>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _STATUS1;
#[doc = "`read()` method returns [status1::R](status1::R) reader structure"]
impl crate::Readable for STATUS1 {}
#[doc = "Interrupt 1 status. Interrupt 1 contains window comparator results and register last LAST_SAMPLE\\[M\\] overrun."]
pub mod status1;
#[doc = "Interrupt 1 clear status\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [clr_stat1](clr_stat1) module"]
pub type CLR_STAT1 = crate::Reg<u32, _CLR_STAT1>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CLR_STAT1;
#[doc = "`write(|w| ..)` method takes [clr_stat1::W](clr_stat1::W) writer structure"]
impl crate::Writable for CLR_STAT1 {}
#[doc = "Interrupt 1 clear status"]
pub mod clr_stat1;
#[doc = "Interrupt 1 set status\n\nThis register you can [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [set_stat1](set_stat1) module"]
pub type SET_STAT1 = crate::Reg<u32, _SET_STAT1>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _SET_STAT1;
#[doc = "`write(|w| ..)` method takes [set_stat1::W](set_stat1::W) writer structure"]
impl crate::Writable for SET_STAT1 {}
#[doc = "Interrupt 1 set status"]
pub mod set_stat1;
