#[doc = r"Register block"]
#[repr(C)]
pub struct RegisterBlock {
    _reserved0: [u8; 256usize],
    #[doc = "0x100 - Capability register length"]
    pub caplength: CAPLENGTH,
    #[doc = "0x104 - Host controller structural parameters"]
    pub hcsparams: HCSPARAMS,
    #[doc = "0x108 - Host controller capability parameters"]
    pub hccparams: HCCPARAMS,
    _reserved3: [u8; 20usize],
    #[doc = "0x120 - Device interface version number"]
    pub dciversion: DCIVERSION,
    _reserved4: [u8; 28usize],
    _reserved_4_usbcmd: [u8; 4usize],
    _reserved_5_usbsts: [u8; 4usize],
    _reserved_6_usbintr: [u8; 4usize],
    _reserved_7_frindex: [u8; 4usize],
    _reserved8: [u8; 4usize],
    _reserved_8_deviceaddr: [u8; 4usize],
    _reserved_9_asynclistaddr: [u8; 4usize],
    #[doc = "0x15c - Asynchronous buffer status for embedded TT (host mode)"]
    pub ttctrl: TTCTRL,
    #[doc = "0x160 - Programmable burst size"]
    pub burstsize: BURSTSIZE,
    #[doc = "0x164 - Host transmit pre-buffer packet tuning (host mode)"]
    pub txfilltuning: TXFILLTUNING,
    _reserved13: [u8; 8usize],
    #[doc = "0x170 - ULPI viewport"]
    pub ulpiviewport: ULPIVIEWPORT,
    #[doc = "0x174 - Length of virtual frame"]
    pub binterval: BINTERVAL,
    #[doc = "0x178 - Endpoint NAK (device mode)"]
    pub endptnak: ENDPTNAK,
    #[doc = "0x17c - Endpoint NAK Enable (device mode)"]
    pub endptnaken: ENDPTNAKEN,
    _reserved17: [u8; 4usize],
    _reserved_17_portsc1: [u8; 4usize],
    _reserved18: [u8; 32usize],
    _reserved_18_usbmode: [u8; 4usize],
    #[doc = "0x1ac - Endpoint setup status"]
    pub endptsetupstat: ENDPTSETUPSTAT,
    #[doc = "0x1b0 - Endpoint initialization"]
    pub endptprime: ENDPTPRIME,
    #[doc = "0x1b4 - Endpoint de-initialization"]
    pub endptflush: ENDPTFLUSH,
    #[doc = "0x1b8 - Endpoint status"]
    pub endptstat: ENDPTSTAT,
    #[doc = "0x1bc - Endpoint complete"]
    pub endptcomplete: ENDPTCOMPLETE,
    #[doc = "0x1c0 - Endpoint control 0"]
    pub endptctrl0: ENDPTCTRL0,
    #[doc = "0x1c4 - Endpoint control"]
    pub endptctrl1: ENDPTCTRL,
    #[doc = "0x1c8 - Endpoint control"]
    pub endptctrl2: ENDPTCTRL,
    #[doc = "0x1cc - Endpoint control"]
    pub endptctrl3: ENDPTCTRL,
}
impl RegisterBlock {
    #[doc = "0x140 - USB command (host mode)"]
    #[inline(always)]
    pub fn usbcmd_h(&self) -> &USBCMD_H {
        unsafe { &*(((self as *const Self) as *const u8).add(320usize) as *const USBCMD_H) }
    }
    #[doc = "0x140 - USB command (host mode)"]
    #[inline(always)]
    pub fn usbcmd_h_mut(&self) -> &mut USBCMD_H {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(320usize) as *mut USBCMD_H) }
    }
    #[doc = "0x140 - USB command (device mode)"]
    #[inline(always)]
    pub fn usbcmd_d(&self) -> &USBCMD_D {
        unsafe { &*(((self as *const Self) as *const u8).add(320usize) as *const USBCMD_D) }
    }
    #[doc = "0x140 - USB command (device mode)"]
    #[inline(always)]
    pub fn usbcmd_d_mut(&self) -> &mut USBCMD_D {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(320usize) as *mut USBCMD_D) }
    }
    #[doc = "0x144 - USB status (host mode)"]
    #[inline(always)]
    pub fn usbsts_h(&self) -> &USBSTS_H {
        unsafe { &*(((self as *const Self) as *const u8).add(324usize) as *const USBSTS_H) }
    }
    #[doc = "0x144 - USB status (host mode)"]
    #[inline(always)]
    pub fn usbsts_h_mut(&self) -> &mut USBSTS_H {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(324usize) as *mut USBSTS_H) }
    }
    #[doc = "0x144 - USB status (device mode)"]
    #[inline(always)]
    pub fn usbsts_d(&self) -> &USBSTS_D {
        unsafe { &*(((self as *const Self) as *const u8).add(324usize) as *const USBSTS_D) }
    }
    #[doc = "0x144 - USB status (device mode)"]
    #[inline(always)]
    pub fn usbsts_d_mut(&self) -> &mut USBSTS_D {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(324usize) as *mut USBSTS_D) }
    }
    #[doc = "0x148 - USB interrupt enable (host mode)"]
    #[inline(always)]
    pub fn usbintr_h(&self) -> &USBINTR_H {
        unsafe { &*(((self as *const Self) as *const u8).add(328usize) as *const USBINTR_H) }
    }
    #[doc = "0x148 - USB interrupt enable (host mode)"]
    #[inline(always)]
    pub fn usbintr_h_mut(&self) -> &mut USBINTR_H {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(328usize) as *mut USBINTR_H) }
    }
    #[doc = "0x148 - USB interrupt enable (device mode)"]
    #[inline(always)]
    pub fn usbintr_d(&self) -> &USBINTR_D {
        unsafe { &*(((self as *const Self) as *const u8).add(328usize) as *const USBINTR_D) }
    }
    #[doc = "0x148 - USB interrupt enable (device mode)"]
    #[inline(always)]
    pub fn usbintr_d_mut(&self) -> &mut USBINTR_D {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(328usize) as *mut USBINTR_D) }
    }
    #[doc = "0x14c - USB frame index (host mode)"]
    #[inline(always)]
    pub fn frindex_h(&self) -> &FRINDEX_H {
        unsafe { &*(((self as *const Self) as *const u8).add(332usize) as *const FRINDEX_H) }
    }
    #[doc = "0x14c - USB frame index (host mode)"]
    #[inline(always)]
    pub fn frindex_h_mut(&self) -> &mut FRINDEX_H {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(332usize) as *mut FRINDEX_H) }
    }
    #[doc = "0x14c - USB frame index (device mode)"]
    #[inline(always)]
    pub fn frindex_d(&self) -> &FRINDEX_D {
        unsafe { &*(((self as *const Self) as *const u8).add(332usize) as *const FRINDEX_D) }
    }
    #[doc = "0x14c - USB frame index (device mode)"]
    #[inline(always)]
    pub fn frindex_d_mut(&self) -> &mut FRINDEX_D {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(332usize) as *mut FRINDEX_D) }
    }
    #[doc = "0x154 - Frame list base address"]
    #[inline(always)]
    pub fn periodiclistbase(&self) -> &PERIODICLISTBASE {
        unsafe { &*(((self as *const Self) as *const u8).add(340usize) as *const PERIODICLISTBASE) }
    }
    #[doc = "0x154 - Frame list base address"]
    #[inline(always)]
    pub fn periodiclistbase_mut(&self) -> &mut PERIODICLISTBASE {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(340usize) as *mut PERIODICLISTBASE) }
    }
    #[doc = "0x154 - USB device address"]
    #[inline(always)]
    pub fn deviceaddr(&self) -> &DEVICEADDR {
        unsafe { &*(((self as *const Self) as *const u8).add(340usize) as *const DEVICEADDR) }
    }
    #[doc = "0x154 - USB device address"]
    #[inline(always)]
    pub fn deviceaddr_mut(&self) -> &mut DEVICEADDR {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(340usize) as *mut DEVICEADDR) }
    }
    #[doc = "0x158 - Address of endpoint list in memory (host mode)"]
    #[inline(always)]
    pub fn asynclistaddr(&self) -> &ASYNCLISTADDR {
        unsafe { &*(((self as *const Self) as *const u8).add(344usize) as *const ASYNCLISTADDR) }
    }
    #[doc = "0x158 - Address of endpoint list in memory (host mode)"]
    #[inline(always)]
    pub fn asynclistaddr_mut(&self) -> &mut ASYNCLISTADDR {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(344usize) as *mut ASYNCLISTADDR) }
    }
    #[doc = "0x158 - Address of endpoint list in memory (device mode)"]
    #[inline(always)]
    pub fn endpointlistaddr(&self) -> &ENDPOINTLISTADDR {
        unsafe { &*(((self as *const Self) as *const u8).add(344usize) as *const ENDPOINTLISTADDR) }
    }
    #[doc = "0x158 - Address of endpoint list in memory (device mode)"]
    #[inline(always)]
    pub fn endpointlistaddr_mut(&self) -> &mut ENDPOINTLISTADDR {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(344usize) as *mut ENDPOINTLISTADDR) }
    }
    #[doc = "0x184 - Port 1 status/control (host mode)"]
    #[inline(always)]
    pub fn portsc1_h(&self) -> &PORTSC1_H {
        unsafe { &*(((self as *const Self) as *const u8).add(388usize) as *const PORTSC1_H) }
    }
    #[doc = "0x184 - Port 1 status/control (host mode)"]
    #[inline(always)]
    pub fn portsc1_h_mut(&self) -> &mut PORTSC1_H {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(388usize) as *mut PORTSC1_H) }
    }
    #[doc = "0x184 - Port 1 status/control (device mode)"]
    #[inline(always)]
    pub fn portsc1_d(&self) -> &PORTSC1_D {
        unsafe { &*(((self as *const Self) as *const u8).add(388usize) as *const PORTSC1_D) }
    }
    #[doc = "0x184 - Port 1 status/control (device mode)"]
    #[inline(always)]
    pub fn portsc1_d_mut(&self) -> &mut PORTSC1_D {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(388usize) as *mut PORTSC1_D) }
    }
    #[doc = "0x1a8 - USB mode (host mode)"]
    #[inline(always)]
    pub fn usbmode_h(&self) -> &USBMODE_H {
        unsafe { &*(((self as *const Self) as *const u8).add(424usize) as *const USBMODE_H) }
    }
    #[doc = "0x1a8 - USB mode (host mode)"]
    #[inline(always)]
    pub fn usbmode_h_mut(&self) -> &mut USBMODE_H {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(424usize) as *mut USBMODE_H) }
    }
    #[doc = "0x1a8 - USB mode (device mode)"]
    #[inline(always)]
    pub fn usbmode_d(&self) -> &USBMODE_D {
        unsafe { &*(((self as *const Self) as *const u8).add(424usize) as *const USBMODE_D) }
    }
    #[doc = "0x1a8 - USB mode (device mode)"]
    #[inline(always)]
    pub fn usbmode_d_mut(&self) -> &mut USBMODE_D {
        unsafe { &mut *(((self as *const Self) as *mut u8).add(424usize) as *mut USBMODE_D) }
    }
}
#[doc = "Capability register length\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [caplength](caplength) module"]
pub type CAPLENGTH = crate::Reg<u32, _CAPLENGTH>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _CAPLENGTH;
#[doc = "`read()` method returns [caplength::R](caplength::R) reader structure"]
impl crate::Readable for CAPLENGTH {}
#[doc = "Capability register length"]
pub mod caplength;
#[doc = "Host controller structural parameters\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [hcsparams](hcsparams) module"]
pub type HCSPARAMS = crate::Reg<u32, _HCSPARAMS>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _HCSPARAMS;
#[doc = "`read()` method returns [hcsparams::R](hcsparams::R) reader structure"]
impl crate::Readable for HCSPARAMS {}
#[doc = "Host controller structural parameters"]
pub mod hcsparams;
#[doc = "Host controller capability parameters\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [hccparams](hccparams) module"]
pub type HCCPARAMS = crate::Reg<u32, _HCCPARAMS>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _HCCPARAMS;
#[doc = "`read()` method returns [hccparams::R](hccparams::R) reader structure"]
impl crate::Readable for HCCPARAMS {}
#[doc = "Host controller capability parameters"]
pub mod hccparams;
#[doc = "Device interface version number\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [dciversion](dciversion) module"]
pub type DCIVERSION = crate::Reg<u32, _DCIVERSION>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DCIVERSION;
#[doc = "`read()` method returns [dciversion::R](dciversion::R) reader structure"]
impl crate::Readable for DCIVERSION {}
#[doc = "Device interface version number"]
pub mod dciversion;
#[doc = "USB command (device mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [usbcmd_d](usbcmd_d) module"]
pub type USBCMD_D = crate::Reg<u32, _USBCMD_D>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _USBCMD_D;
#[doc = "`read()` method returns [usbcmd_d::R](usbcmd_d::R) reader structure"]
impl crate::Readable for USBCMD_D {}
#[doc = "`write(|w| ..)` method takes [usbcmd_d::W](usbcmd_d::W) writer structure"]
impl crate::Writable for USBCMD_D {}
#[doc = "USB command (device mode)"]
pub mod usbcmd_d;
#[doc = "USB command (host mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [usbcmd_h](usbcmd_h) module"]
pub type USBCMD_H = crate::Reg<u32, _USBCMD_H>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _USBCMD_H;
#[doc = "`read()` method returns [usbcmd_h::R](usbcmd_h::R) reader structure"]
impl crate::Readable for USBCMD_H {}
#[doc = "`write(|w| ..)` method takes [usbcmd_h::W](usbcmd_h::W) writer structure"]
impl crate::Writable for USBCMD_H {}
#[doc = "USB command (host mode)"]
pub mod usbcmd_h;
#[doc = "USB status (device mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [usbsts_d](usbsts_d) module"]
pub type USBSTS_D = crate::Reg<u32, _USBSTS_D>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _USBSTS_D;
#[doc = "`read()` method returns [usbsts_d::R](usbsts_d::R) reader structure"]
impl crate::Readable for USBSTS_D {}
#[doc = "`write(|w| ..)` method takes [usbsts_d::W](usbsts_d::W) writer structure"]
impl crate::Writable for USBSTS_D {}
#[doc = "USB status (device mode)"]
pub mod usbsts_d;
#[doc = "USB status (host mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [usbsts_h](usbsts_h) module"]
pub type USBSTS_H = crate::Reg<u32, _USBSTS_H>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _USBSTS_H;
#[doc = "`read()` method returns [usbsts_h::R](usbsts_h::R) reader structure"]
impl crate::Readable for USBSTS_H {}
#[doc = "`write(|w| ..)` method takes [usbsts_h::W](usbsts_h::W) writer structure"]
impl crate::Writable for USBSTS_H {}
#[doc = "USB status (host mode)"]
pub mod usbsts_h;
#[doc = "USB interrupt enable (device mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [usbintr_d](usbintr_d) module"]
pub type USBINTR_D = crate::Reg<u32, _USBINTR_D>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _USBINTR_D;
#[doc = "`read()` method returns [usbintr_d::R](usbintr_d::R) reader structure"]
impl crate::Readable for USBINTR_D {}
#[doc = "`write(|w| ..)` method takes [usbintr_d::W](usbintr_d::W) writer structure"]
impl crate::Writable for USBINTR_D {}
#[doc = "USB interrupt enable (device mode)"]
pub mod usbintr_d;
#[doc = "USB interrupt enable (host mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [usbintr_h](usbintr_h) module"]
pub type USBINTR_H = crate::Reg<u32, _USBINTR_H>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _USBINTR_H;
#[doc = "`read()` method returns [usbintr_h::R](usbintr_h::R) reader structure"]
impl crate::Readable for USBINTR_H {}
#[doc = "`write(|w| ..)` method takes [usbintr_h::W](usbintr_h::W) writer structure"]
impl crate::Writable for USBINTR_H {}
#[doc = "USB interrupt enable (host mode)"]
pub mod usbintr_h;
#[doc = "USB frame index (device mode)\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [frindex_d](frindex_d) module"]
pub type FRINDEX_D = crate::Reg<u32, _FRINDEX_D>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _FRINDEX_D;
#[doc = "`read()` method returns [frindex_d::R](frindex_d::R) reader structure"]
impl crate::Readable for FRINDEX_D {}
#[doc = "USB frame index (device mode)"]
pub mod frindex_d;
#[doc = "USB frame index (host mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [frindex_h](frindex_h) module"]
pub type FRINDEX_H = crate::Reg<u32, _FRINDEX_H>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _FRINDEX_H;
#[doc = "`read()` method returns [frindex_h::R](frindex_h::R) reader structure"]
impl crate::Readable for FRINDEX_H {}
#[doc = "`write(|w| ..)` method takes [frindex_h::W](frindex_h::W) writer structure"]
impl crate::Writable for FRINDEX_H {}
#[doc = "USB frame index (host mode)"]
pub mod frindex_h;
#[doc = "USB device address\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [deviceaddr](deviceaddr) module"]
pub type DEVICEADDR = crate::Reg<u32, _DEVICEADDR>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _DEVICEADDR;
#[doc = "`read()` method returns [deviceaddr::R](deviceaddr::R) reader structure"]
impl crate::Readable for DEVICEADDR {}
#[doc = "`write(|w| ..)` method takes [deviceaddr::W](deviceaddr::W) writer structure"]
impl crate::Writable for DEVICEADDR {}
#[doc = "USB device address"]
pub mod deviceaddr;
#[doc = "Frame list base address\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [periodiclistbase](periodiclistbase) module"]
pub type PERIODICLISTBASE = crate::Reg<u32, _PERIODICLISTBASE>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _PERIODICLISTBASE;
#[doc = "`read()` method returns [periodiclistbase::R](periodiclistbase::R) reader structure"]
impl crate::Readable for PERIODICLISTBASE {}
#[doc = "`write(|w| ..)` method takes [periodiclistbase::W](periodiclistbase::W) writer structure"]
impl crate::Writable for PERIODICLISTBASE {}
#[doc = "Frame list base address"]
pub mod periodiclistbase;
#[doc = "Address of endpoint list in memory (device mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [endpointlistaddr](endpointlistaddr) module"]
pub type ENDPOINTLISTADDR = crate::Reg<u32, _ENDPOINTLISTADDR>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENDPOINTLISTADDR;
#[doc = "`read()` method returns [endpointlistaddr::R](endpointlistaddr::R) reader structure"]
impl crate::Readable for ENDPOINTLISTADDR {}
#[doc = "`write(|w| ..)` method takes [endpointlistaddr::W](endpointlistaddr::W) writer structure"]
impl crate::Writable for ENDPOINTLISTADDR {}
#[doc = "Address of endpoint list in memory (device mode)"]
pub mod endpointlistaddr;
#[doc = "Address of endpoint list in memory (host mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [asynclistaddr](asynclistaddr) module"]
pub type ASYNCLISTADDR = crate::Reg<u32, _ASYNCLISTADDR>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ASYNCLISTADDR;
#[doc = "`read()` method returns [asynclistaddr::R](asynclistaddr::R) reader structure"]
impl crate::Readable for ASYNCLISTADDR {}
#[doc = "`write(|w| ..)` method takes [asynclistaddr::W](asynclistaddr::W) writer structure"]
impl crate::Writable for ASYNCLISTADDR {}
#[doc = "Address of endpoint list in memory (host mode)"]
pub mod asynclistaddr;
#[doc = "Asynchronous buffer status for embedded TT (host mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [ttctrl](ttctrl) module"]
pub type TTCTRL = crate::Reg<u32, _TTCTRL>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _TTCTRL;
#[doc = "`read()` method returns [ttctrl::R](ttctrl::R) reader structure"]
impl crate::Readable for TTCTRL {}
#[doc = "`write(|w| ..)` method takes [ttctrl::W](ttctrl::W) writer structure"]
impl crate::Writable for TTCTRL {}
#[doc = "Asynchronous buffer status for embedded TT (host mode)"]
pub mod ttctrl;
#[doc = "Programmable burst size\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [burstsize](burstsize) module"]
pub type BURSTSIZE = crate::Reg<u32, _BURSTSIZE>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _BURSTSIZE;
#[doc = "`read()` method returns [burstsize::R](burstsize::R) reader structure"]
impl crate::Readable for BURSTSIZE {}
#[doc = "`write(|w| ..)` method takes [burstsize::W](burstsize::W) writer structure"]
impl crate::Writable for BURSTSIZE {}
#[doc = "Programmable burst size"]
pub mod burstsize;
#[doc = "Host transmit pre-buffer packet tuning (host mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [txfilltuning](txfilltuning) module"]
pub type TXFILLTUNING = crate::Reg<u32, _TXFILLTUNING>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _TXFILLTUNING;
#[doc = "`read()` method returns [txfilltuning::R](txfilltuning::R) reader structure"]
impl crate::Readable for TXFILLTUNING {}
#[doc = "`write(|w| ..)` method takes [txfilltuning::W](txfilltuning::W) writer structure"]
impl crate::Writable for TXFILLTUNING {}
#[doc = "Host transmit pre-buffer packet tuning (host mode)"]
pub mod txfilltuning;
#[doc = "ULPI viewport\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [ulpiviewport](ulpiviewport) module"]
pub type ULPIVIEWPORT = crate::Reg<u32, _ULPIVIEWPORT>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ULPIVIEWPORT;
#[doc = "`read()` method returns [ulpiviewport::R](ulpiviewport::R) reader structure"]
impl crate::Readable for ULPIVIEWPORT {}
#[doc = "`write(|w| ..)` method takes [ulpiviewport::W](ulpiviewport::W) writer structure"]
impl crate::Writable for ULPIVIEWPORT {}
#[doc = "ULPI viewport"]
pub mod ulpiviewport;
#[doc = "Length of virtual frame\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [binterval](binterval) module"]
pub type BINTERVAL = crate::Reg<u32, _BINTERVAL>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _BINTERVAL;
#[doc = "`read()` method returns [binterval::R](binterval::R) reader structure"]
impl crate::Readable for BINTERVAL {}
#[doc = "`write(|w| ..)` method takes [binterval::W](binterval::W) writer structure"]
impl crate::Writable for BINTERVAL {}
#[doc = "Length of virtual frame"]
pub mod binterval;
#[doc = "Endpoint NAK (device mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [endptnak](endptnak) module"]
pub type ENDPTNAK = crate::Reg<u32, _ENDPTNAK>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENDPTNAK;
#[doc = "`read()` method returns [endptnak::R](endptnak::R) reader structure"]
impl crate::Readable for ENDPTNAK {}
#[doc = "`write(|w| ..)` method takes [endptnak::W](endptnak::W) writer structure"]
impl crate::Writable for ENDPTNAK {}
#[doc = "Endpoint NAK (device mode)"]
pub mod endptnak;
#[doc = "Endpoint NAK Enable (device mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [endptnaken](endptnaken) module"]
pub type ENDPTNAKEN = crate::Reg<u32, _ENDPTNAKEN>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENDPTNAKEN;
#[doc = "`read()` method returns [endptnaken::R](endptnaken::R) reader structure"]
impl crate::Readable for ENDPTNAKEN {}
#[doc = "`write(|w| ..)` method takes [endptnaken::W](endptnaken::W) writer structure"]
impl crate::Writable for ENDPTNAKEN {}
#[doc = "Endpoint NAK Enable (device mode)"]
pub mod endptnaken;
#[doc = "Port 1 status/control (device mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [portsc1_d](portsc1_d) module"]
pub type PORTSC1_D = crate::Reg<u32, _PORTSC1_D>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _PORTSC1_D;
#[doc = "`read()` method returns [portsc1_d::R](portsc1_d::R) reader structure"]
impl crate::Readable for PORTSC1_D {}
#[doc = "`write(|w| ..)` method takes [portsc1_d::W](portsc1_d::W) writer structure"]
impl crate::Writable for PORTSC1_D {}
#[doc = "Port 1 status/control (device mode)"]
pub mod portsc1_d;
#[doc = "Port 1 status/control (host mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [portsc1_h](portsc1_h) module"]
pub type PORTSC1_H = crate::Reg<u32, _PORTSC1_H>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _PORTSC1_H;
#[doc = "`read()` method returns [portsc1_h::R](portsc1_h::R) reader structure"]
impl crate::Readable for PORTSC1_H {}
#[doc = "`write(|w| ..)` method takes [portsc1_h::W](portsc1_h::W) writer structure"]
impl crate::Writable for PORTSC1_H {}
#[doc = "Port 1 status/control (host mode)"]
pub mod portsc1_h;
#[doc = "USB mode (device mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [usbmode_d](usbmode_d) module"]
pub type USBMODE_D = crate::Reg<u32, _USBMODE_D>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _USBMODE_D;
#[doc = "`read()` method returns [usbmode_d::R](usbmode_d::R) reader structure"]
impl crate::Readable for USBMODE_D {}
#[doc = "`write(|w| ..)` method takes [usbmode_d::W](usbmode_d::W) writer structure"]
impl crate::Writable for USBMODE_D {}
#[doc = "USB mode (device mode)"]
pub mod usbmode_d;
#[doc = "USB mode (host mode)\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [usbmode_h](usbmode_h) module"]
pub type USBMODE_H = crate::Reg<u32, _USBMODE_H>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _USBMODE_H;
#[doc = "`read()` method returns [usbmode_h::R](usbmode_h::R) reader structure"]
impl crate::Readable for USBMODE_H {}
#[doc = "`write(|w| ..)` method takes [usbmode_h::W](usbmode_h::W) writer structure"]
impl crate::Writable for USBMODE_H {}
#[doc = "USB mode (host mode)"]
pub mod usbmode_h;
#[doc = "Endpoint setup status\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [endptsetupstat](endptsetupstat) module"]
pub type ENDPTSETUPSTAT = crate::Reg<u32, _ENDPTSETUPSTAT>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENDPTSETUPSTAT;
#[doc = "`read()` method returns [endptsetupstat::R](endptsetupstat::R) reader structure"]
impl crate::Readable for ENDPTSETUPSTAT {}
#[doc = "`write(|w| ..)` method takes [endptsetupstat::W](endptsetupstat::W) writer structure"]
impl crate::Writable for ENDPTSETUPSTAT {}
#[doc = "Endpoint setup status"]
pub mod endptsetupstat;
#[doc = "Endpoint initialization\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [endptprime](endptprime) module"]
pub type ENDPTPRIME = crate::Reg<u32, _ENDPTPRIME>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENDPTPRIME;
#[doc = "`read()` method returns [endptprime::R](endptprime::R) reader structure"]
impl crate::Readable for ENDPTPRIME {}
#[doc = "`write(|w| ..)` method takes [endptprime::W](endptprime::W) writer structure"]
impl crate::Writable for ENDPTPRIME {}
#[doc = "Endpoint initialization"]
pub mod endptprime;
#[doc = "Endpoint de-initialization\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [endptflush](endptflush) module"]
pub type ENDPTFLUSH = crate::Reg<u32, _ENDPTFLUSH>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENDPTFLUSH;
#[doc = "`read()` method returns [endptflush::R](endptflush::R) reader structure"]
impl crate::Readable for ENDPTFLUSH {}
#[doc = "`write(|w| ..)` method takes [endptflush::W](endptflush::W) writer structure"]
impl crate::Writable for ENDPTFLUSH {}
#[doc = "Endpoint de-initialization"]
pub mod endptflush;
#[doc = "Endpoint status\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [endptstat](endptstat) module"]
pub type ENDPTSTAT = crate::Reg<u32, _ENDPTSTAT>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENDPTSTAT;
#[doc = "`read()` method returns [endptstat::R](endptstat::R) reader structure"]
impl crate::Readable for ENDPTSTAT {}
#[doc = "Endpoint status"]
pub mod endptstat;
#[doc = "Endpoint complete\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [endptcomplete](endptcomplete) module"]
pub type ENDPTCOMPLETE = crate::Reg<u32, _ENDPTCOMPLETE>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENDPTCOMPLETE;
#[doc = "`read()` method returns [endptcomplete::R](endptcomplete::R) reader structure"]
impl crate::Readable for ENDPTCOMPLETE {}
#[doc = "`write(|w| ..)` method takes [endptcomplete::W](endptcomplete::W) writer structure"]
impl crate::Writable for ENDPTCOMPLETE {}
#[doc = "Endpoint complete"]
pub mod endptcomplete;
#[doc = "Endpoint control 0\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [endptctrl0](endptctrl0) module"]
pub type ENDPTCTRL0 = crate::Reg<u32, _ENDPTCTRL0>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENDPTCTRL0;
#[doc = "`read()` method returns [endptctrl0::R](endptctrl0::R) reader structure"]
impl crate::Readable for ENDPTCTRL0 {}
#[doc = "`write(|w| ..)` method takes [endptctrl0::W](endptctrl0::W) writer structure"]
impl crate::Writable for ENDPTCTRL0 {}
#[doc = "Endpoint control 0"]
pub mod endptctrl0;
#[doc = "Endpoint control\n\nThis register you can [`read`](crate::generic::Reg::read), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about avaliable fields see [endptctrl](endptctrl) module"]
pub type ENDPTCTRL = crate::Reg<u32, _ENDPTCTRL>;
#[allow(missing_docs)]
#[doc(hidden)]
pub struct _ENDPTCTRL;
#[doc = "`read()` method returns [endptctrl::R](endptctrl::R) reader structure"]
impl crate::Readable for ENDPTCTRL {}
#[doc = "`write(|w| ..)` method takes [endptctrl::W](endptctrl::W) writer structure"]
impl crate::Writable for ENDPTCTRL {}
#[doc = "Endpoint control"]
pub mod endptctrl;
